LogLevel class

Implemented types

Constructors

LogLevel(String name, int value)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

compareTo(LogLevel other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator <(LogLevel other) → bool
operator <=(LogLevel other) → bool
operator ==(Object other) → bool
The equality operator.
override
operator >(LogLevel other) → bool
operator >=(LogLevel other) → bool

Constants

all → const LogLevel
debug → const LogLevel
error → const LogLevel
info → const LogLevel
levels → const List<LogLevel>
off → const LogLevel
trace → const LogLevel
warn → const LogLevel