HttpRequestManager class

Constructors

HttpRequestManager()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

isPost ↔ bool
getter/setter pair

Static Methods

get(String url) → Future<({int code, String data, bool success})>
post(String url, String body) → Future<({int code, String data, bool success})>
send(String url) → Future<({int code, String data, bool success})>