ResourceManager class

Constructors

ResourceManager(SystemManager systemManager, ApplicationStorage applicationStorage, DeviceStorage deviceStorage, SessionStorage sessionStorage, VolatileStorage volatileStorage)

Properties

applicationStorage → ApplicationStorage
final
deviceStorage → DeviceStorage
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionStorage → SessionStorage
final
systemManager → SystemManager
final
volatileStorage → VolatileStorage
final

Methods

clearSessionAttrs() → Future<void>
getAllAttrs([BuildContext? context]) → Future<Map<String, dynamic>>
getCustomId() → String
getDeviceId() → String
getSessionAttrs() → Map<String, dynamic>
getUserId() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCustomId(String value) → Future<void>
setDeviceId(String value) → Future<void>
setSessionAttrs(Map<String, String> attrs) → Future<void>
setUserId(String value) → Future<void>
toString() → String
A string representation of this object.
inherited
updateAppState(bool foreground) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

newInstance(SystemManager systemManager, Config config) → Future<ResourceManager>