DeviceStorage class

Inheritance

Constructors

DeviceStorage(StorageType type, Config config)

Properties

config → Config
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → StorageType
finalinherited

Methods

clear() → Future<bool>
inherited
getAll() → Map<String, dynamic>
inherited
getCustomId() → String
getDeviceId() → String
getIntOr(String key, int defaultValue) → int
inherited
getKeys() → Set<String>
inherited
getString(String key) → String
inherited
getStringOr(String key, String defaultValue) → String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putAll(Map<String, String> map) → Future<bool>
inherited
putInt(String key, int value) → Future<bool>
inherited
putString(String key, String value) → Future<bool>
inherited
remove(String key) → Future<bool>
inherited
setCustomId(String value) → Future<void>
setDeviceId(String value) → Future<void>
toString() → String
A string representation of this object.
inherited
update() → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

newInstance(Config config) → Future<DeviceStorage>