Storage class

Implementers

Constructors

Storage(StorageType type)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → StorageType
final

Methods

clear() → Future<bool>
getAll() → Map<String, dynamic>
getIntOr(String key, int defaultValue) → int
getKeys() → Set<String>
getString(String key) → String
getStringOr(String key, String defaultValue) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putAll(Map<String, String> map) → Future<bool>
putInt(String key, int value) → Future<bool>
putString(String key, String value) → Future<bool>
remove(String key) → Future<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

preferences ↔ SharedPreferences?
getter/setter pair

Static Methods

init() → Future<void>

Constants

invalidUuid → const String
uuid → const Uuid