VolatileStorage class

Inheritance
Implementers

Constructors

VolatileStorage(StorageType type)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → StorageType
finalinherited

Methods

clear() → Future<bool>
inherited
getAll() → Map<String, dynamic>
inherited
getIntOr(String key, int defaultValue) → int
inherited
getKeys() → Set<String>
inherited
getString(String key) → String
inherited
getStringOr(String key, String defaultValue) → String
inherited
init() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putAll(Map<String, String> map) → Future<bool>
inherited
putInt(String key, int value) → Future<bool>
inherited
putString(String key, String value) → Future<bool>
inherited
remove(String key) → Future<bool>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

newInstance() → Future<VolatileStorage>